@@ -46,8 +46,6 @@
 
 package Users::Users;
 
-use Authen::PAM;
-
 use Utils::Util;
 use Utils::Report;
 use Utils::File;
@@ -92,6 +90,7 @@ my $ENC_HOME      = $i++;
 my $HOME_FLAGS    = $i++;
 my $LOCALE        = $i++;
 my $LOCATION      = $i++;
+my $FACE          = $i++;
 
 %login_defs_prop_map = ();
 %profiles_prop_map = ();
@@ -382,6 +381,7 @@ sub get
     $users_hash{$login}[$HOME_FLAGS] = 0;
     $users_hash{$login}[$LOCALE] = "";
     $users_hash{$login}[$LOCATION] = "";
+    $users_hash{$login}[$FACE] = "";
   }
 
   &Utils::File::close_file ($ifh);
@@ -464,34 +464,6 @@ sub change_user_chfn
   &Utils::File::run (@command);
 }
 
-# modifies /etc/shadow directly, not good practice,
-# but better than passing clean passwords around
-sub modify_shadow_password
-{
-  my ($login, $password) = @_;
-  my ($buffer, $i, @arr);
-
-  $buffer = &Utils::File::load_buffer (@shadow_names);
-  return if (!$buffer);
-  $i = 0;
-
-  while ($$buffer[$i])
-  {
-    @arr = split ':', $$buffer[$i], -1;
-
-    if ($arr[0] eq $login)
-    {
-      $arr[1] = $password;
-      $$buffer[$i] = join (':', @arr) . "\n";
-      last;
-    }
-
-    $i++;
-  }
-
-  &Utils::File::save_buffer ($buffer, @shadow_names);
-}
-
 sub set_passwd
 {
   my ($login, $password) = @_;
@@ -596,6 +568,13 @@ sub add_user
       push (@command, ("--shell", $$user[$SHELL])) if ($$user[$SHELL]);
       push (@command, ("--uid", $$user[$UID])) if ($real_uid);
       push (@command, ("--gid", $$user[$GID])) if ($real_gid);
+
+      # Allow encrypted home if the tool is present
+      if ($$user[$ENC_HOME] && &Utils::File::locate_tool ("mount.ecryptfs"))
+      {
+        push (@command, "--encrypt-home");
+      }
+
       push (@command, $$user[$LOGIN]);
 
       &Utils::File::run (@command);
